@@ -34,7 +34,7 @@
  *
  */
 
-/* $Id: skkpalette.c,v 1.1.2.6 2003/02/12 22:20:52 famao Exp $ */
+/* $Id: skkpalette.c,v 1.4 2003/02/19 17:44:50 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -106,7 +106,7 @@ static void _palette_reposition (SkkPalette *palette);
 static GdkFilterReturn _ext_event_handler (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data);
 
 static void _status_changed (gchar *text, gint type);
-static void set_menu (gint type);
+static void _set_menu (GtkWidget *menu, gint type, gpointer data);
 
 /* Menu Detach */
 static void _menu_detach_func (GtkWidget *attach_widget, GtkMenu *menu);
@@ -246,8 +246,14 @@ static void
 _status_menu_activate (GtkMenuItem *menu_item, gpointer user_data)
 {
 	gint send_status[1];
-	send_status[0] = GPOINTER_TO_INT (menu_item_get_activate_data (GTK_WIDGET (menu_item)));
-	skk_aux_palette_send_engine (1, send_status, 0, NULL);
+#ifdef USE_GTK2
+	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menu_item))) {
+#else
+	if (GTK_CHECK_MENU_ITEM (menu_item)->active) {
+#endif
+		send_status[0] = GPOINTER_TO_INT (menu_item_get_activate_data (GTK_WIDGET (menu_item)));
+		skk_aux_palette_send_engine (1, send_status, 0, NULL);
+	}
 }
 
 static void
@@ -279,11 +285,9 @@ _code_button_clicked (GtkWidget *widget, gpointer user_data)
 }
 
 static void
-set_menu (gint type)
+_set_menu (GtkWidget *menu, gint type, gpointer data)
 {
-	GtkWidget *menu;
 	GtkWidget *menuitem;
-	menu = SKK_PALETTE_MENU (g_palette);
 	if (!menu)
 		return;
 	switch (type) {
@@ -311,9 +315,9 @@ set_menu (gint type)
 	}
 	if (!menuitem)
 		return;
-#if 0
+	gtk_signal_handler_block_by_data (GTK_OBJECT (menuitem), data);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
-#endif
+	gtk_signal_handler_unblock_by_data (GTK_OBJECT (menuitem), data);
 	return;
 
 }
@@ -447,7 +451,10 @@ xaux_ext_Draw (xaux_class_t *xc, aux_ext_data_t *aux_ext_data)
 			case SKK_MODE_JISX0208_LATIN:
 				_status_changed (aux_ext_data->string_list[i].ptr,
 						aux_ext_data->integer_list[i]);
-				set_menu (aux_ext_data->integer_list[i]);
+				_set_menu (SKK_PALETTE_MENU (g_palette), aux_ext_data->integer_list[i], 
+						(gpointer) g_palette);
+				_set_menu (skk_tray_window_get_menu (SKK_TRAY (g_palette)), aux_ext_data->integer_list[i],
+						(gpointer) SKK_TRAY (g_palette));
 				break;
 			case SKK_MODE_OFF:
 #if 1
