@@ -32,7 +32,7 @@
  *
  */
 
-/* $Id: skkcannadictimpl.c,v 1.1.2.5 2002/10/28 05:06:15 famao Exp $ */
+/* $Id: skkcannadictimpl.c,v 1.3 2003/02/19 17:44:51 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -138,8 +138,9 @@ static SkkQueryFunctionImpl *
 get_new (SkkQuery *query)
 {
 	SkkCannaDictImpl *impl;
+	jrKanjiStatus *pks;
 	impl = g_new0 (SkkCannaDictImpl, 1);
-	jrKanjiStatus *pks = g_new0 (jrKanjiStatus, 1);
+	pks = g_new0 (jrKanjiStatus, 1);
 	impl->impl = dictimpl;
 	impl->context_id = context_id;
 	context_id++;
