@@ -1,7 +1,8 @@
 #ifndef HAVE_SKKDICTIMPL_H
 #define HAVE_SKKDICTIMPL_H
 #include <glib.h>
-#include "skkqueryimpl.h"
+#include <skkqueryimpl.h>
+#include <skkquery.h>
 
 typedef struct _SkkDictImpl SkkDictImpl;
 
@@ -9,8 +10,10 @@ struct _SkkDictImpl
 {
 	SkkQueryFunctionImpl impl;
 	gint sock;
+	gchar *hostname;
+	gchar *port;
 };
 
-SkkQueryFunctionImpl *skk_dict_new (void);
+SkkQueryFunctionImpl *skk_dict_new (SkkQuery *query);
 
 #endif /* HAVE_SKKDICTIMPL_H */
