@@ -34,7 +34,7 @@
  *
  */
 
-/* $Id: skk.c,v 1.9.2.27 2003/02/12 22:09:21 famao Exp $ */
+/* $Id: skk.c,v 1.18 2003/02/19 17:44:53 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -216,6 +216,7 @@ static void skk_process_auxevent (iml_session_t *s, IMAuxDrawCallbackStruct *aux
 
 static void skk_aux_status_draw (iml_session_t *s);
 static void skk_aux_status_draw_off (iml_session_t *s);
+static void skk_aux_status_update (iml_session_t *s);
 
 /* String */
 static IMText *skk_utftoimtext (iml_session_t * s, UTFCHAR * p);
@@ -770,7 +771,7 @@ skk_codetable_listener (SkkBuffer *buf, gpointer user_data)
 	return;
 }
 
-Bool
+static Bool
 if_skk_CreateSC (iml_session_t * s, IMArgList args, int num_args)
 {
 	SkkDesktopData *d = skk_desktop_data (s);
@@ -804,7 +805,7 @@ if_skk_CreateSC (iml_session_t * s, IMArgList args, int num_args)
 	return True;
 }
 
-Bool
+static Bool
 if_skk_DestroySC (iml_session_t * s)
 {
 	SkkSessionData *ses;
@@ -814,7 +815,7 @@ if_skk_DestroySC (iml_session_t * s)
 	return True;
 }
 
-Bool
+static Bool
 if_skk_GetSCValues (iml_session_t * s, IMArgList args, int num_args)
 {
 	int i;
@@ -841,7 +842,7 @@ if_skk_GetSCValues (iml_session_t * s, IMArgList args, int num_args)
 	return True;
 }
 
-Bool
+static Bool
 if_skk_SetSCValues (iml_session_t * s, IMArgList args, int num_args)
 {
 	int i;
@@ -885,7 +886,7 @@ if_skk_SetSCValues (iml_session_t * s, IMArgList args, int num_args)
 	return True;
 }
 
-IMText *
+static IMText *
 if_skk_ResetSC (iml_session_t *s)
 {
 	iml_inst *lp;
@@ -894,14 +895,14 @@ if_skk_ResetSC (iml_session_t *s)
 	return (IMText *) NULL;
 }
 
-void
+static void
 if_skk_SetSCFocus (iml_session_t *s)
 {
 	skk_status_draw (s);
 	return;
 }
 
-void
+static void
 if_skk_UnsetSCFocus (iml_session_t * s)
 {
 #ifdef DEBUG
@@ -911,7 +912,7 @@ if_skk_UnsetSCFocus (iml_session_t * s)
 #endif  
 }
 
-void
+static void
 if_skk_SendEvent (iml_session_t *s, IMInputEvent *ev)
 {
 #ifdef DEBUG
@@ -1822,6 +1823,23 @@ skk_aux_status_draw_off (iml_session_t *s)
 	return;
 }
 
+static void
+skk_aux_status_update (iml_session_t *s)
+{
+	iml_desktop_t *desktop = s->desktop;
+	iml_session_list session_list = desktop->session_list;
+	iml_session_t *tmp;
+	SkkDesktopData *d = skk_desktop_data (s);
+	SkkBuffer *buf;
+
+	for (tmp = (iml_session_t *)session_list; tmp; tmp = tmp->next) {
+		buf = skk_session_buf (tmp);
+		skk_buffer_set_conf (buf, d->skkconf);
+	}
+	skk_aux_status_draw (s);
+	return;
+}
+
 static void
 skk_aux_status_draw (iml_session_t *s)
 {
@@ -2212,6 +2230,7 @@ skk_process_auxevent (iml_session_t *s, IMAuxDrawCallbackStruct *aux)
 					skk_conv_rule_clear (d->skkconv);
 					/* skk_conf_clear (d->skkconf); */
 					skk_conf_load_rc (d->skkconf, s->desktop->user_name);
+					skk_aux_status_update (s);
 				}
 				break;
 
